@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: ftp.c,v 1.61 2001/03/14 18:24:07 bagder Exp $
+ * $Id: ftp.c,v 1.63 2001/04/03 10:20:23 bagder Exp $
  *****************************************************************************/
 
 #include "setup.h"
@@ -78,6 +78,7 @@
 #endif
 
 #include "strequal.h"
+#include "ssluse.h"
 
 #define _MPRINTF_REPLACE /* use our functions only */
 #include <curl/mprintf.h>
@@ -316,6 +317,14 @@ CURLcode Curl_ftp_connect(struct connectdata *conn)
       return result;
   }
 
+  if(conn->protocol & PROT_FTPS) {
+    /* FTPS is simply ftp with SSL for the control channel */
+    /* now, perform the SSL initialization for this socket */
+    if(Curl_SSLConnect(conn))
+      return CURLE_SSL_CONNECT_ERROR;
+  }
+
+
   /* The first thing we do is wait for the "220*" line: */
   nread = Curl_GetFTPResponse(conn->firstsocket, buf, conn, &ftpcode);
   if(nread < 0)
@@ -337,8 +346,6 @@ CURLcode Curl_ftp_connect(struct connectdata *conn)
        set a valid level */
     sec_request_prot(conn, data->krb4_level);
 
-    data->cmdchannel = fdopen(conn->firstsocket, "w");
-
     if(sec_login(conn) != 0)
       infof(data, "Logging in with password in cleartext!\n");
     else
@@ -1702,16 +1709,9 @@ size_t Curl_ftpsendf(int fd, struct connectdata *conn, char *fmt, ...)
 
   strcat(s, "\r\n"); /* append a trailing CRLF */
 
-#ifdef KRB4
-  if(conn->sec_complete && conn->data->cmdchannel) {
-    bytes_written = sec_fprintf(conn, conn->data->cmdchannel, s);
-    fflush(conn->data->cmdchannel);
-  }
-  else
-#endif /* KRB4 */
-    {
-      bytes_written = swrite(fd, s, strlen(s));
-    }
+  bytes_written=0;
+  Curl_write(conn, fd, s, strlen(s), &bytes_written);
+
   return(bytes_written);
 }
 
@@ -1720,12 +1720,14 @@ CURLcode Curl_ftp_disconnect(struct connectdata *conn)
 {
   struct FTP *ftp= conn->proto.ftp;
 
-  if(ftp->user)
-    free(ftp->user);
-  if(ftp->passwd)
-    free(ftp->passwd);
-  if(ftp->entrypath)
-    free(ftp->entrypath);
-
+  /* The FTP session may or may not have been allocated/setup at this point! */
+  if(ftp) {
+    if(ftp->user)
+      free(ftp->user);
+    if(ftp->passwd)
+      free(ftp->passwd);
+    if(ftp->entrypath)
+      free(ftp->entrypath);
+  }
   return CURLE_OK;
 }
