@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: netrc.c,v 1.9 2001/02/07 08:36:23 bagder Exp $
+ * $Id: netrc.c,v 1.12 2001/03/16 15:19:36 bagder Exp $
  *****************************************************************************/
 
 #include "setup.h"
@@ -27,10 +27,26 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef HAVE_PWD_H
+#include <pwd.h>
+#endif
+
+
 #include <curl/curl.h>
 
 #include "strequal.h"
 
+/* The last #include file should be: */
+#ifdef MALLOCDEBUG
+#include "memdebug.h"
+#endif
+
 /* Debug this single source file with:
    'make netrc' then run './netrc'!
 
@@ -60,7 +76,7 @@ int Curl_parsenetrc(char *host,
   char netrcbuffer[256];
   int retcode=1;
   
-  char *home = curl_getenv("HOME"); /* portable environment reader */
+  char *home = NULL; 
   int state=NOTHING;
 
   char state_login=0;
@@ -68,11 +84,25 @@ int Curl_parsenetrc(char *host,
 
 #define NETRC DOT_CHAR "netrc"
 
-  if(!home)
-    return -1;
+#if defined(HAVE_GETPWUID) && defined(HAVE_GETEUID)
+  struct passwd *pw;
+  pw= getpwuid(geteuid());
+  if (pw)
+    home = pw->pw_dir;
+#else
+  void *pw=NULL;
+#endif
+  
+  if(NULL == pw) {
+    home = curl_getenv("HOME"); /* portable environment reader */
+    if(!home) {
+      return -1;
+    }
+  }
 
   if(strlen(home)>(sizeof(netrcbuffer)-strlen(NETRC))) {
-    free(home);
+    if(NULL==pw)
+      free(home);
     return -1;
   }
 
@@ -140,7 +170,8 @@ int Curl_parsenetrc(char *host,
     fclose(file);
   }
 
-  free(home);
+  if(NULL==pw)
+    free(home);
 
   return retcode;
 }
