@@ -5,38 +5,21 @@
  *                            | (__| |_| |  _ <| |___ 
  *                             \___|\___/|_| \_\_____|
  *
- *  The contents of this file are subject to the Mozilla Public License
- *  Version 1.0 (the "License"); you may not use this file except in
- *  compliance with the License. You may obtain a copy of the License at
- *  http://www.mozilla.org/MPL/
+ * Copyright (C) 2000, Daniel Stenberg, <daniel@haxx.se>, et al.
  *
- *  Software distributed under the License is distributed on an "AS IS"
- *  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
- *  License for the specific language governing rights and limitations
- *  under the License.
+ * In order to be useful for every potential user, curl and libcurl are
+ * dual-licensed under the MPL and the MIT/X-derivate licenses.
  *
- *  The Original Code is Curl.
+ * You may opt to use, copy, modify, merge, publish, distribute and/or sell
+ * copies of the Software, and permit persons to whom the Software is
+ * furnished to do so, under the terms of the MPL or the MIT/X-derivate
+ * licenses. You may pick one of these licenses.
  *
- *  The Initial Developer of the Original Code is Daniel Stenberg.
+ * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
+ * KIND, either express or implied.
  *
- *  Portions created by the Initial Developer are Copyright (C) 1998.
- *  All Rights Reserved.
- *
- * ------------------------------------------------------------
- * Main author:
- * - Daniel Stenberg <daniel@haxx.se>
- *
- * 	http://curl.haxx.se
- *
- * $Source: /cvsroot/curl/lib/timeval.c,v $
- * $Revision: 1.3 $
- * $Date: 2000/06/20 15:31:26 $
- * $Author: bagder $
- * $State: Exp $
- * $Locker:  $
- *
- * ------------------------------------------------------------
- ****************************************************************************/
+ * $Id: timeval.c,v 1.6 2001/03/13 07:53:06 bagder Exp $
+ *****************************************************************************/
 
 #ifdef WIN32
 #include <windows.h>
@@ -70,7 +53,7 @@ gettimeofday (struct timeval *tp, void *nothing)
 #endif
 #endif
 
-struct timeval tvnow ()
+struct timeval Curl_tvnow (void)
 {
  struct timeval now;
 #ifdef HAVE_GETTIMEOFDAY
@@ -82,12 +65,12 @@ struct timeval tvnow ()
  return now;
 }
 
-double tvdiff (struct timeval t1, struct timeval t2)
+double Curl_tvdiff (struct timeval t1, struct timeval t2)
 {
  return (double)(t1.tv_sec - t2.tv_sec) + ((t1.tv_usec-t2.tv_usec)/1000000.0);
 }
 
-long tvlong (struct timeval t1)
+long Curl_tvlong (struct timeval t1)
 {
  return t1.tv_sec;
 }
