@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: transfer.c,v 1.23 2001/03/19 07:47:57 bagder Exp $
+ * $Id: transfer.c,v 1.32 2001/04/03 13:37:53 bagder Exp $
  *****************************************************************************/
 
 #include "setup.h"
@@ -356,11 +356,10 @@ Transfer(struct connectdata *c_conn)
                   /*
                    * end-of-headers.
                    *
-                   * If we requested a "no body" and this isn't a "close"
-                   * connection, this is a good time to get out and return
-                   * home.
+                   * If we requested a "no body", this is a good time to get
+                   * out and return home.
                    */
-                  if(!conn->bits.close && data->bits.no_body)
+                  if(data->bits.no_body)
                     return CURLE_OK;
                   break;		/* exit header line loop */
                 }
@@ -423,6 +422,18 @@ Transfer(struct connectdata *c_conn)
                 conn->bits.close = FALSE; /* don't close when done */
                 infof(data, "HTTP/1.0 proxy connection set to keep alive!\n");
               }
+              else if((httpversion == 0) &&
+                      strnequal("Connection: keep-alive", p,
+                                strlen("Connection: keep-alive"))) {
+                /*
+                 * A HTTP/1.0 reply with the 'Connection: keep-alive' line
+                 * tells us the connection will be kept alive for our
+                 * pleasure.  Default action for 1.0 is to close.
+                 *
+                 * [RFC2068, section 19.7.1] */
+                conn->bits.close = FALSE; /* don't close when done */
+                infof(data, "HTTP/1.0 connection set to keep alive!\n");
+              }
               else if (strnequal("Connection: close", p,
                                  strlen("Connection: close"))) {
                 /*
@@ -736,6 +747,10 @@ CURLcode Curl_perform(CURL *curl)
   struct UrlData *data = (struct UrlData *)curl;
   struct connectdata *conn=NULL;
   bool port=TRUE; /* allow data->use_port to set port to use */
+  char *newurl = NULL; /* possibly a new URL to follow to! */
+
+  data->followlocation=0; /* reset the location-follow counter */
+  data->bits.this_is_a_follow = FALSE; /* reset this */
 
   Curl_pgrsStartNow(data);
 
@@ -746,11 +761,23 @@ CURLcode Curl_perform(CURL *curl)
       res = Curl_do(conn);
       if(res == CURLE_OK) {
         res = Transfer(conn); /* now fetch that URL please */
-        if(res == CURLE_OK)
+        if(res == CURLE_OK) {
+          /*
+           * We must duplicate the new URL here as the connection data
+           * may be free()ed in the Curl_done() function.
+           */
+          newurl = conn->newurl?strdup(conn->newurl):NULL;
+
           res = Curl_done(conn);
+        }
       }
 
-      if((res == CURLE_OK) && conn->newurl) {
+      /*
+       * Important: 'conn' cannot be used here, since it may have been closed
+       * in 'Curl_done' or other functions.
+       */
+
+      if((res == CURLE_OK) && newurl) {
         /* Location: redirect
  
            This is assumed to happen for HTTP(S) only!
@@ -763,9 +790,6 @@ CURLcode Curl_perform(CURL *curl)
 
 	if (data->maxredirs && (data->followlocation >= data->maxredirs)) {
 	  failf(data,"Maximum (%d) redirects followed", data->maxredirs);
-#ifdef USE_OLD_DISCONNECT
-          curl_disconnect(c_connect);
-#endif
           res=CURLE_TOO_MANY_REDIRECTS;
 	  break;
 	}
@@ -790,7 +814,7 @@ CURLcode Curl_perform(CURL *curl)
           data->bits.http_set_referer = TRUE; /* might have been false */
         }
 
-        if(2 != sscanf(conn->newurl, "%15[^:]://%c", prot, &letter)) {
+        if(2 != sscanf(newurl, "%15[^:]://%c", prot, &letter)) {
           /***
            *DANG* this is an RFC 2068 violation. The URL is supposed
            to be absolute and this doesn't seem to be that!
@@ -803,19 +827,21 @@ CURLcode Curl_perform(CURL *curl)
           char *pathsep;
           char *newest;
 
+          /* we must make our own copy of the URL to play with, as it may
+             point to read-only data */
+          char *url_clone=strdup(data->url);
+
+          if(!url_clone)
+            return CURLE_OUT_OF_MEMORY;
+
           /* protsep points to the start of the host name */
-          protsep=strstr(data->url, "//");
+          protsep=strstr(url_clone, "//");
           if(!protsep)
-            protsep=data->url;
-          else {
-            port=FALSE; /* we got a full URL and thus we should not obey the
-                           port number that might have been set by the user
-                           in data->use_port */
-
+            protsep=url_clone;
+          else
             protsep+=2; /* pass the slashes */
-          }
 
-          if('/' != conn->newurl[0]) {
+          if('/' != newurl[0]) {
             /* First we need to find out if there's a ?-letter in the URL,
                and cut it and the right-side of that off */
             pathsep = strrchr(protsep, '?');
@@ -836,16 +862,17 @@ CURLcode Curl_perform(CURL *curl)
               *pathsep=0;
           }
 
-          newest=(char *)malloc( strlen(data->url) +
+          newest=(char *)malloc( strlen(url_clone) +
                                  1 + /* possible slash */
-                                 strlen(conn->newurl) + 1/* zero byte */);
+                                 strlen(newurl) + 1/* zero byte */);
 
           if(!newest)
             return CURLE_OUT_OF_MEMORY;
-          sprintf(newest, "%s%s%s", data->url, ('/' == conn->newurl[0])?"":"/",
-                  conn->newurl);
-          free(conn->newurl);
-          conn->newurl = newest;
+          sprintf(newest, "%s%s%s", url_clone, ('/' == newurl[0])?"":"/",
+                  newurl);
+          free(newurl);
+          free(url_clone);
+          newurl = newest;
         }
         else {
           /* This is an absolute URL, don't use the custom port number */
@@ -856,8 +883,8 @@ CURLcode Curl_perform(CURL *curl)
           free(data->url);
       
         /* TBD: set the URL with curl_setopt() */
-        data->url = conn->newurl;
-        conn->newurl = NULL; /* don't show! */
+        data->url = newurl;
+
         data->bits.urlstringalloc = TRUE; /* the URL is allocated */
 
         infof(data, "Follows Location: to new URL: '%s'\n", data->url);
@@ -871,7 +898,6 @@ CURLcode Curl_perform(CURL *curl)
         switch(data->progress.httpcode) {
         case 300: /* Multiple Choices */
         case 301: /* Moved Permanently */
-        case 302: /* Found */
         case 306: /* Not used */
         case 307: /* Temporary Redirect */
         default:  /* for all unknown ones */
@@ -879,6 +905,24 @@ CURLcode Curl_perform(CURL *curl)
            * seem to be OK to POST to.
            */
           break;
+        case 302: /* Found */
+          /* (From 10.3.3)
+
+            Note: RFC 1945 and RFC 2068 specify that the client is not allowed
+            to change the method on the redirected request.  However, most
+            existing user agent implementations treat 302 as if it were a 303
+            response, performing a GET on the Location field-value regardless
+            of the original request method. The status codes 303 and 307 have
+            been added for servers that wish to make unambiguously clear which
+            kind of reaction is expected of the client.
+
+            (From 10.3.4)
+
+            Note: Many pre-HTTP/1.1 user agents do not understand the 303
+            status. When interoperability with such clients is a concern, the
+            302 status code may be used instead, since most user agents react
+            to a 302 response as described here for 303.             
+          */
         case 303: /* See Other */
           /* Disable both types of POSTs, since doing a second POST when
            * following isn't what anyone would want! */
@@ -902,24 +946,19 @@ CURLcode Curl_perform(CURL *curl)
            */
           break;
         }
-#ifdef USE_OLD_DISCONNECT
-        curl_disconnect(c_connect);
-#endif
         continue;
       }
-
-#ifdef USE_OLD_DISCONNECT
-      curl_disconnect(c_connect);
-#endif
     }
     break; /* it only reaches here when this shouldn't loop */
 
   } while(1); /* loop if Location: */
 
-  if(conn->newurl) {
-    free(conn->newurl);
-    conn->newurl = NULL;
-  }
+  if(newurl)
+    free(newurl);
+
+  /* make sure the alarm is switched off! */
+  if(data->timeout || data->connecttimeout)
+    myalarm(0);
 
   return res;
 }
