@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: url.c,v 1.107 2001/03/15 14:38:30 bagder Exp $
+ * $Id: url.c,v 1.110 2001/04/03 10:20:23 bagder Exp $
  *****************************************************************************/
 
 /* -- WIN32 approved -- */
@@ -816,6 +816,9 @@ CURLcode Curl_disconnect(struct connectdata *conn)
     free(conn->hostent_buf);
 #endif
 
+  if(conn->newurl)
+    free(conn->newurl);
+
   if(conn->path) /* the URL path part */
     free(conn->path);
 
@@ -936,9 +939,11 @@ ConnectionExists(struct UrlData *data,
           data->connects[i]=NULL; /* nothing here */
           continue; /* try another one now */
         }
+
+        *usethis = check;
+        return TRUE; /* yes, we found one to use! */
+        
       }
-      *usethis = check;
-      return TRUE; /* yes, we found one to use! */
     }
     else { /* The requested needle connection is using a proxy,
               is the checked one using the same? */
@@ -1397,6 +1402,8 @@ static CURLcode Connect(struct UrlData *data,
 #ifdef USE_SSLEAY
       else if(strnequal(conn->gname, "HTTPS", 5))
         strcpy(conn->protostr, "https");
+      else if(strnequal(conn->gname, "FTPS", 4))
+        strcpy(conn->protostr, "ftps");
 #endif /* USE_SSLEAY */
       else if(strnequal(conn->gname, "TELNET", 6))
         strcpy(conn->protostr, "telnet");
@@ -1666,8 +1673,19 @@ static CURLcode Connect(struct UrlData *data,
     conn->curl_done = Curl_http_done;
     conn->curl_close = Curl_http_close;
   }
-  else if(strequal(conn->protostr, "FTP")) {
+  else if(strequal(conn->protostr, "FTP") ||
+          strequal(conn->protostr, "FTPS")) {
     char *type;
+
+    if(strequal(conn->protostr, "FTPS")) {
+#ifdef USE_SSLEAY
+      conn->protocol |= PROT_FTPS;
+#else
+      failf(data, "libcurl was built with SSL disabled, ftps: not supported!");
+      return CURLE_UNSUPPORTED_PROTOCOL;
+#endif /* !USE_SSLEAY */
+    }
+
     conn->port = (data->use_port && allow_port)?data->use_port:PORT_FTP;
     conn->remote_port = PORT_FTP;
     conn->protocol |= PROT_FTP;
@@ -1676,6 +1694,12 @@ static CURLcode Connect(struct UrlData *data,
        !data->bits.tunnel_thru_httpproxy) {
       /* Unless we have asked to tunnel ftp operations through the proxy, we
          switch and use HTTP operations only */
+      if(conn->protocol & PROT_FTPS) {
+        /* FTPS is a hacked protocol and does not work through your
+           ordinary http proxy! */
+        failf(data, "ftps does not work through http proxy!");
+        return CURLE_UNSUPPORTED_PROTOCOL;
+      }
       conn->curl_do = Curl_http;
       conn->curl_done = Curl_http_done;
       conn->curl_close = Curl_http_close;
@@ -2126,8 +2150,10 @@ CURLcode Curl_connect(struct UrlData *data,
     /* We're not allowed to return failure with memory left allocated
        in the connectdata struct, free those here */
     conn = (struct connectdata *)*in_connect;
-    if(conn)
+    if(conn) {
       Curl_disconnect(conn);      /* close the connection */
+      *in_connect = NULL;         /* return a NULL */
+    }
   }
   return code;
 }
