@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: runtests.pl,v 1.20 2001/01/29 15:07:28 bagder Exp $
+# $Id: runtests.pl,v 1.25 2001/03/13 22:14:53 bagder Exp $
 #
 # Main curl test script, in perl to run on more platforms
 #
@@ -51,6 +51,7 @@ my $short;
 my $verbose;
 my $debugprotocol;
 my $anyway;
+my $gdbthis; # run test case with gdb debugger
 
 #######################################################################
 # Return the pid of the server as found in the given pid file
@@ -153,6 +154,10 @@ sub runftpserver {
 
     if ($RUNNING != 1) {
         my $flag=$debugprotocol?"-v ":"";
+        if($debugprotocol) {
+            print "* Starts ftp server verbose:\n";
+            print "perl $srcdir/ftpserver.pl $flag $FTPPORT &\n";
+        }
         system("perl $srcdir/ftpserver.pl $flag $FTPPORT &");
         sleep 1; # give it a little time to start
     }
@@ -351,7 +356,7 @@ sub singletest {
     if(! -r $CURLCMD) {
         # this is not a test
         print "$NUMBER doesn't look like a test case!\n";
-        next;
+        return -1;
     }
 
     # remove previous server output logfile
@@ -397,12 +402,13 @@ sub singletest {
     }
 
     # run curl, add -v for debug information output
-    my $CMDLINE="$CURL $out--include -v --silent $cmd >$STDOUT 2>$STDERR";
+    my $cmdargs="$out--include -v --silent $cmd";
 
     my $STDINFILE="$TESTDIR/stdin$NUMBER.txt";
     if(-f $STDINFILE) {
-        $CMDLINE .= " < $STDINFILE";
+        $cmdargs .= " < $STDINFILE";
     }
+    my $CMDLINE="$CURL $cmdargs >$STDOUT 2>$STDERR";
 
     if($verbose) {
         print "$CMDLINE\n";
@@ -410,9 +416,20 @@ sub singletest {
 
     print CMDLOG "$CMDLINE\n";
 
+    my $res;
     # run the command line we built
-    my $res = system("$CMDLINE");
-    $res /= 256;
+    if($gdbthis) {
+        open(GDBCMD, ">log/gdbcmd");
+        print GDBCMD "set args $cmdargs\n";
+        print GDBCMD "show args\n";
+        close(GDBCMD);
+        system("gdb $CURL -x log/gdbcmd");
+        $res =0; # makes it always continue after a debugged run
+    }
+    else {
+        $res = system("$CMDLINE");
+        $res /= 256;
+    }
 
     my $ERRORCODE = "$TESTDIR/error$NUMBER.txt";
 
@@ -550,6 +567,8 @@ sub singletest {
 # Check options to this test program
 #
 
+my $number=0;
+my $fromnum=-1;
 my @testthis;
 do {
     if ($ARGV[0] eq "-v") {
@@ -560,6 +579,10 @@ do {
         # have the servers display protocol output 
         $debugprotocol=1;
     }
+    elsif ($ARGV[0] eq "-g") {
+        # run this test with gdb
+        $gdbthis=1;
+    }
     elsif($ARGV[0] eq "-s") {
         # short output
         $short=1;
@@ -574,6 +597,7 @@ do {
 Usage: runtests.pl [-h][-s][-v][numbers]
   -a       continue even if a test fails
   -d       display server debug info
+  -g       run the test case with gdb
   -h       this help text
   -s       short output
   -v       verbose output
@@ -583,7 +607,19 @@ EOHELP
         exit;
     }
     elsif($ARGV[0] =~ /^(\d+)/) {
-        push @testthis, $1;
+        $number = $1;
+        if($fromnum >= 0) {
+            for($fromnum .. $number) {
+                push @testthis, $_;
+            }
+            $fromnum = -1;
+        }
+        else {
+            push @testthis, $1;
+        }
+    }
+    elsif($ARGV[0] =~ /^to$/i) {
+        $fromnum = $number+1;
     }
 } while(shift @ARGV);
 
@@ -643,17 +679,24 @@ open(CMDLOG, ">$CURLLOG") ||
 # The main test-loop
 #
 
+my $failed;
 my $testnum;
 my $ok=0;
 my $total=0;
 foreach $testnum (split(" ", $TESTCASES)) {
 
-    $total++;
     my $error = singletest($testnum);
-    if($error && !$anyway) {
-        # a test failed, abort
-        print "\n - abort tests\n";
-        last;
+    if(-1 != $error) {
+        # valid test case number
+        $total++;
+    }
+    if($error>0) {
+        if(!$anyway) {
+            # a test failed, abort
+            print "\n - abort tests\n";
+            last;
+        }
+        $failed.= "$testnum ";
     }
     elsif(!$error) {
         $ok++;
@@ -674,4 +717,13 @@ close(CMDLOG);
 stopserver($FTPPIDFILE);
 stopserver($PIDFILE);
 
-print "$ok tests out of $total reported OK\n";
+if($total) {
+    print "$ok tests out of $total reported OK\n";
+
+    if($ok != $total) {
+        print "These test cases failed: $failed\n";
+    }
+}
+else {
+    print "No tests were performed!\n";
+}
